==> spip_3.2.11.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Inserì un À',
	'barre_adresse' => 'Adressa',
	'barre_aide' => 'Utilisas li escourcha tipougràfiqui da enriquì la vouòstra coumpaginacioun',
	'barre_alignerdroite' => '[/Aligna a drecha/] lou paràgrafou',
	'barre_ancres' => 'Gestioun dei àncoura',
	'barre_barre' => 'Serà lou tèst',
	'barre_bulle' => 'Boufa d’ajuda',
	'barre_c_cedille_maj' => 'Inserì un Ç',
	'barre_cadre' => 'Metre dintre d’una &lt;cadre&gt;zona sesìda de tèst&lt;/cadre&gt;',
	'barre_caracteres' => 'Caracter especial',
	'barre_centrer' => '[|Centrà|] lou paràgrafou',
	'barre_chercher' => 'Cercà Remplaçà',
	'barre_clean' => 'Netegià lou code de touti li balisa HTML',
	'barre_code' => 'Metre en fourma un &lt;code&gt;code infourmàticou&lt;/code&gt;',
	'barre_desindenter' => 'Desindentà una lista',
	'barre_e_accent_aigu' => 'Inserì un É',
	'barre_e_accent_grave' => 'Inserì un È',
	'barre_ea' => 'Inserì un æ',
	'barre_ea_maj' => 'Inserì un Æ',
	'barre_encadrer' => '[(Encadrà)] lou paràgrafou',
	'barre_eo' => 'Inserì un œ',
	'barre_eo_maj' => 'Inserì un Œ',
	'barre_euro' => 'Inserì le symbole €',
	'barre_exposant' => 'Metre lou tèst en &lt;sup&gt;espounent&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Fourmatage especial',
	'barre_galerie' => 'Durbì la galerìa',
	'barre_gestion_anc_bulle' => 'Boufa d’ajuda àncoura',
	'barre_gestion_anc_caption' => 'Gestioun dei àncoura',
	'barre_gestion_anc_cible' => 'Àncoura bressai',
	'barre_gestion_anc_inserer' => 'Trasfourmà en àncoura',
	'barre_gestion_anc_nom' => 'Noum de l’àncoura',
	'barre_gestion_anc_pointer' => 'Pountà devers una àncoura',
	'barre_gestion_caption' => 'Legenda e Coumpèndi',
	'barre_gestion_colonne' => 'Nb coulòna',
	'barre_gestion_cr_casse' => 'Respetà la cassa',
	'barre_gestion_cr_changercasse' => 'Cambià la cassa',
	'barre_gestion_cr_changercassemajuscules' => 'Passà en maiùscoula',
	'barre_gestion_cr_changercasseminuscules' => 'Passà en minùscula',
	'barre_gestion_cr_chercher' => 'Cercà',
	'barre_gestion_cr_entier' => 'Mot entié',
	'barre_gestion_cr_remplacer' => 'Remplaça',
	'barre_gestion_cr_tout' => 'Remplaça tout',
	'barre_gestion_entete' => 'Prima-testa',
	'barre_gestion_ligne' => 'Nb ligna',
	'barre_gestion_taille' => 'Talha fissa',
	'barre_glossaire' => 'Intrada dóu [?gloussari] (Wikipedia)',
	'barre_gras' => 'Metre en {{gras}}',
	'barre_guillemets' => 'Entourà embé de « virgouleta »',
	'barre_guillemets_simples' => 'Entourà embé de “virgouleta de segount nivèu”',
	'barre_indenter' => 'Indentà una lista',
	'barre_inserer_cadre' => 'Inserà un code prefourmatat (cadre)',
	'barre_inserer_caracteres' => 'Inserà dei caracter espechìficou',
	'barre_inserer_code' => 'Insà un code infourmàticou (code)',
	'barre_intertitre' => 'Trasfourmà en {{{intertitre}}}',
	'barre_italic' => 'Metre en {itàlicou}',
	'barre_langue' => 'Lenga abreviada',
	'barre_lien' => 'Trasfourmà en [estac ipèrtest->http://...]',
	'barre_lien_externe' => 'Estac estèrnou',
	'barre_lien_input' => 'Vourguès endicà l’adressa dóu vouòstre estac (poudès endicà una adressa web souta la forma http://www.loumieusit.com o simplamen endicà lou nùmero d’un article d’aqueu sit).',
	'barre_liste_ol' => 'Metre en lista numeroutada',
	'barre_liste_ul' => 'Metre en lista',
	'barre_lorem_ipsum' => 'Inserà un paràgrafou fatìci',
	'barre_lorem_ipsum_3' => 'Inserà tré paràgrafou fatìci',
	'barre_miseenevidence' => 'Metre lou tèst en [*evidença*]',
	'barre_note' => 'Trasfourmà en [[Nota de bas de pàgina]]',
	'barre_paragraphe' => 'Creà un paràgrafou',
	'barre_petitescapitales' => 'Metre lou tèst en &lt;sc&gt;capitaleta&lt;/sc&gt;',
	'barre_poesie' => 'Metre en fourma couma una &lt;poesie&gt;pouesìa&lt;/poesie&gt;',
	'barre_preview' => 'Mòdou previsualisacioun',
	'barre_quote' => '<quote>Cità un message</quote>',
	'barre_stats' => 'Afichà li estatìstica dóu tèst',
	'barre_tableau' => 'Inserà/moudificà (lou seleciounà denant) un tabléu',

	// C
	'config_info_enregistree' => 'Counfiguracioun sauvagardada',

	// E
	'editer' => 'Edità',
	'explication_barre_outils_public' => 'Lu script CSS e Javascript dei barra d’óutis
	(estencioun Pouòta Pluma) soun cargat soubre l’espaci pùblicou
	e permeton d’utilisà aqueli barra soubre lu fourmulari dei fòrou,
	lu creioun pùblicou o d’autre plugin, se li siéu coufiguracioun
	lì permetoun.',
	'explication_barre_outils_public_2' => 'Poudès chausì de noun cargà
	aquelu scripts afin d’alaugì lou pès dei pàgina pùbliqui.
	Aloura quau que sìgue la counfiguracioun dei fòrou, creioun o plugin,
	mìnga barra d’óutis dóu Pouòrta Pluma noun pourà estre
	presenta  automaticamen soubre l’espaci pùblicou.',

	// I
	'info_barre_outils_public' => 'Barra d’óutis pùbliqui',
	'info_porte_plume_titre' => 'Counfigurà li barra d’óutis',

	// L
	'label_barre_outils_public_non' => 'Noun cargà lu script de barra d’óutis soubre l’espaci pùblicou',
	'label_barre_outils_public_oui' => 'Cargà lu script de barra d’óutis soubre l’espaci pùblicou',

	// V
	'voir' => 'Vèire'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Inserì un À',
	'barre_adresse' => 'Adressa',
	'barre_aide' => 'Utilisas li escourcha tipougràfiqui da enriquì la vouòstra coumpaginacioun',
	'barre_alignerdroite' => '[/Aligna a drecha/] lou paràgrafou',
	'barre_ancres' => 'Gestioun dei àncoura',
	'barre_barre' => 'Serà lou tèst',
	'barre_bulle' => 'Boufa d’ajuda',
	'barre_c_cedille_maj' => 'Inserì un Ç',
	'barre_cadre' => 'Metre dintre d’una &lt;cadre&gt;zona sesìda de tèst&lt;/cadre&gt;',
	'barre_caracteres' => 'Caracter especial',
	'barre_centrer' => '[|Centrà|] lou paràgrafou',
	'barre_chercher' => 'Cercà Remplaçà',
	'barre_clean' => 'Netegià lou code de touti li balisa HTML',
	'barre_code' => 'Metre en fourma un &lt;code&gt;code infourmàticou&lt;/code&gt;',
	'barre_desindenter' => 'Desindentà una lista',
	'barre_e_accent_aigu' => 'Inserì un É',
	'barre_e_accent_grave' => 'Inserì un È',
	'barre_ea' => 'Inserì un æ',
	'barre_ea_maj' => 'Inserì un Æ',
	'barre_encadrer' => '[(Encadrà)] lou paràgrafou',
	'barre_eo' => 'Inserì un œ',
	'barre_eo_maj' => 'Inserì un Œ',
	'barre_euro' => 'Inserì le symbole €',
	'barre_exposant' => 'Metre lou tèst en &lt;sup&gt;espounent&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Fourmatage especial',
	'barre_galerie' => 'Durbì la galerìa',
	'barre_gestion_anc_bulle' => 'Boufa d’ajuda àncoura',
	'barre_gestion_anc_caption' => 'Gestioun dei àncoura',
	'barre_gestion_anc_cible' => 'Àncoura bressai',
	'barre_gestion_anc_inserer' => 'Trasfourmà en àncoura',
	'barre_gestion_anc_nom' => 'Noum de l’àncoura',
	'barre_gestion_anc_pointer' => 'Pountà devers una àncoura',
	'barre_gestion_caption' => 'Legenda e Coumpèndi',
	'barre_gestion_colonne' => 'Nb coulòna',
	'barre_gestion_cr_casse' => 'Respetà la cassa',
	'barre_gestion_cr_changercasse' => 'Cambià la cassa',
	'barre_gestion_cr_changercassemajuscules' => 'Passà en maiùscoula',
	'barre_gestion_cr_changercasseminuscules' => 'Passà en minùscula',
	'barre_gestion_cr_chercher' => 'Cercà',
	'barre_gestion_cr_entier' => 'Mot entié',
	'barre_gestion_cr_remplacer' => 'Remplaça',
	'barre_gestion_cr_tout' => 'Remplaça tout',
	'barre_gestion_entete' => 'Prima-testa',
	'barre_gestion_ligne' => 'Nb ligna',
	'barre_gestion_taille' => 'Talha fissa',
	'barre_glossaire' => 'Intrada dóu [?gloussari] (Wikipedia)',
	'barre_gras' => 'Metre en {{gras}}',
	'barre_guillemets' => 'Entourà embé de « virgouleta »',
	'barre_guillemets_simples' => 'Entourà embé de “virgouleta de segount nivèu”',
	'barre_indenter' => 'Indentà una lista',
	'barre_inserer_cadre' => 'Inserà un code prefourmatat (cadre)', # MODIF
	'barre_inserer_caracteres' => 'Inserà dei caracter espechìficou',
	'barre_inserer_code' => 'Insà un code infourmàticou (code)', # MODIF
	'barre_intertitre' => 'Trasfourmà en {{{intertitre}}}',
	'barre_italic' => 'Metre en {itàlicou}',
	'barre_langue' => 'Lenga abreviada',
	'barre_lien' => 'Trasfourmà en [estac ipèrtest->http://...]',
	'barre_lien_externe' => 'Estac estèrnou',
	'barre_lien_input' => 'Vourguès endicà l’adressa dóu vouòstre estac (poudès endicà una adressa web souta la forma http://www.loumieusit.com o simplamen endicà lou nùmero d’un article d’aqueu sit).',
	'barre_liste_ol' => 'Metre en lista numeroutada',
	'barre_liste_ul' => 'Metre en lista',
	'barre_lorem_ipsum' => 'Inserà un paràgrafou fatìci',
	'barre_lorem_ipsum_3' => 'Inserà tré paràgrafou fatìci',
	'barre_miseenevidence' => 'Metre lou tèst en [*evidença*]',
	'barre_note' => 'Trasfourmà en [[Nota de bas de pàgina]]',
	'barre_paragraphe' => 'Creà un paràgrafou',
	'barre_petitescapitales' => 'Metre lou tèst en &lt;sc&gt;capitaleta&lt;/sc&gt;',
	'barre_poesie' => 'Metre en fourma couma una &lt;poesie&gt;pouesìa&lt;/poesie&gt;',
	'barre_preview' => 'Mòdou previsualisacioun',
	'barre_quote' => '<quote>Cità un message</quote>',
	'barre_stats' => 'Afichà li estatìstica dóu tèst',
	'barre_tableau' => 'Inserà/moudificà (lou seleciounà denant) un tabléu',

	// C
	'config_info_enregistree' => 'Counfiguracioun sauvagardada',

	// E
	'editer' => 'Edità',
	'explication_barre_outils_public' => 'Lu script CSS e Javascript dei barra d’óutis
	(estencioun Pouòta Pluma) soun cargat soubre l’espaci pùblicou
	e permeton d’utilisà aqueli barra soubre lu fourmulari dei fòrou,
	lu creioun pùblicou o d’autre plugin, se li siéu coufiguracioun
	lì permetoun.',
	'explication_barre_outils_public_2' => 'Poudès chausì de noun cargà
	aquelu scripts afin d’alaugì lou pès dei pàgina pùbliqui.
	Aloura quau que sìgue la counfiguracioun dei fòrou, creioun o plugin,
	mìnga barra d’óutis dóu Pouòrta Pluma noun pourà estre
	presenta  automaticamen soubre l’espaci pùblicou.',

	// I
	'info_barre_outils_public' => 'Barra d’óutis pùbliqui',
	'info_porte_plume_titre' => 'Counfigurà li barra d’óutis',

	// L
	'label_barre_outils_public_non' => 'Noun cargà lu script de barra d’óutis soubre l’espaci pùblicou',
	'label_barre_outils_public_oui' => 'Cargà lu script de barra d’óutis soubre l’espaci pùblicou',

	// V
	'voir' => 'Vèire'
);
